package com.antai.sport.http.server.server.api.business.user.controller;

import com.antai.sport.http.server.common.base.Result;
import com.antai.sport.http.server.server.api.business.traininglog.dto.SportUserTrainingLogVO;
import com.antai.sport.http.server.server.api.business.traininglog.dto.TrainingDetailVO;
import com.antai.sport.http.server.server.api.business.traininglog.service.SportUserTrainingLogService;
import com.antai.sport.http.server.server.api.business.user.dto.*;
import com.antai.sport.http.server.server.api.business.user.service.SportUserService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import java.util.List;

import static com.antai.sport.http.server.common.util.ResultUtil.success;

@Api(tags = {"用户相关接口"})
@RestController
@RequestMapping("user")
public class SportUserController {
    @Resource
    private SportUserService sportUserService;
    @Resource
    private SportUserTrainingLogService sportUserTrainingLogService;

    @ApiOperation("查询用户主页数据")
    @GetMapping("{userId}")
    public ResponseEntity<Result<RespUserHomeInfo>> getUserHomeInfo(@PathVariable("userId") Long userId) {
        return success(sportUserService.getUserHomeInfo(userId));
    }

    @ApiOperation("查询用户运动记录")
    @PostMapping("/training/log")
    public ResponseEntity<Result<List<SportUserTrainingLogVO>>> getSportUserTrainingLog(@RequestBody ReqSportUserTrainingLog param) {
        return success(sportUserTrainingLogService.getSportUserTrainingLog(param));
    }

    @ApiOperation("查询我的排名 type: 1能力榜 2活跃度榜")
    @GetMapping("/{userId}/rank")
    public ResponseEntity<Result<SportUserMonthRankResponseDTO>> getMyRank(@PathVariable("userId") Long userId, @RequestParam Integer type, @RequestParam Integer year, @RequestParam Integer month) {
        return success(sportUserTrainingLogService.getMyRank(userId, type, year, month));
    }


    @ApiOperation("查询玩家排名列表")
    @PostMapping("/rank")
    public ResponseEntity<Result<List<SportUserMonthRankResponseDTO>>> geRank(@RequestBody SportUserMonthRankRequestDTO param) {
        return success(sportUserTrainingLogService.geRank(param));
    }


    @ApiOperation("查询玩家运动日历")
    @PostMapping("/{userId}/schedule")
    public ResponseEntity<Result<List<ScheduleResponseDTO>>> getSchedule(@PathVariable("userId") Long userId, @RequestParam Integer year, @RequestParam Integer month) {
        return success(sportUserTrainingLogService.getSchedule(userId, year, month));
    }

    @ApiOperation("查询用户运动记录详情")
    @GetMapping("/training/log/{id}")
    public ResponseEntity<Result<TrainingDetailVO>> getSportUserTrainingLogRank(@PathVariable("id") Long Id) {
        return success(sportUserTrainingLogService.getTrainingDetail(Id));
    }
}
